.. _reference:

Reference
*********

   :Release: |release|
   :Date: |today|

.. toctree::
   :maxdepth: 2

   introduction
   classes/index
   algorithms/index
   functions
   generators
   linalg
   convert
   relabel
   readwrite/index
   drawing
   randomness
   exceptions
   utils
   glossary
